==> rabbitmq-server-3.8.14.tar.xz: rabbitmq-server-3.8.14/README.md <==
[![OTP v22.3](https://img.shields.io/github/workflow/status/rabbitmq/rabbitmq-server/Test%20-%20Erlang%2022.3/master?label=Erlang%2022.3)](https://github.com/rabbitmq/rabbitmq-server/actions?query=workflow%3A%22Test+-+Erlang+22.3%22+branch%3A%22master%22)
[![OTP v23](https://img.shields.io/github/workflow/status/rabbitmq/rabbitmq-server/Test%20-%20Erlang%2023.1/master?label=Erlang%2023.1)](https://github.com/rabbitmq/rabbitmq-server/actions?query=workflow%3A%22Test+-+Erlang+23.1%22+branch%3Amaster)

# RabbitMQ Server

[RabbitMQ](https://rabbitmq.com) is a [feature rich](https://rabbitmq.com/documentation.html), multi-protocol messaging broker. It supports:

 * AMQP 0-9-1
 * AMQP 1.0
 * MQTT 3.1.1
 * STOMP 1.0 through 1.2


## Installation

 * [Installation guides](https://rabbitmq.com/download.html) for various platforms
 * [Kubernetes Cluster Operator](https://www.rabbitmq.com/kubernetes/operator/operator-overview.html)
 * [Changelog](https://www.rabbitmq.com/changelog.html)
 * [Releases](https://github.com/rabbitmq/rabbitmq-server/releases) on GitHub
 * [Supported and unsupported series](https://www.rabbitmq.com/versions.html)
 * [Supported Erlang versions](https://www.rabbitmq.com/which-erlang.html)


## Tutorials & Documentation

 * [RabbitMQ tutorials](https://rabbitmq.com/getstarted.html)
 * [All documentation guides](https://rabbitmq.com/documentation.html)

Some key doc guides include

 * [CLI tools guide](https://rabbitmq.com/cli.html)
 * [Clustering](https://www.rabbitmq.com/clustering.html) and [Cluster Formation](https://www.rabbitmq.com/cluster-formation.html) guides
 * [Configuration guide](https://rabbitmq.com/configure.html)
 * [Client libraries and tools](https://rabbitmq.com/devtools.html)
 * [Monitoring](https://rabbitmq.com/monitoring.html) and [Prometheus/Grafana](https://www.rabbitmq.com/prometheus.html) guides
 * [Production checklist](https://rabbitmq.com/production-checklist.html)
 * [Quorum queues](https://rabbitmq.com/quorum-queues.html): a replicated, data safety- and consistency-oriented queue type
 * [Runnable tutorials](https://github.com/rabbitmq/rabbitmq-tutorials/)
 * [Documentation source](https://github.com/rabbitmq/rabbitmq-website/)


## Commercial Support

* [Commercial support](https://rabbitmq.com/services.html) from [VMware](https://vmware.com) for open source RabbitMQ

## Getting Help from the Community

 * [GitHub Discussions](https://github.com/rabbitmq/rabbitmq-server/discussions/)
 * [RabbitMQ mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users)
 * [Community Slack](https://rabbitmq-slack.herokuapp.com/)
 * `#rabbitmq` on Freenode


## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md) and our [development process overview](https://rabbitmq.com/github.html).

Questions about contributing, internals and so on are very welcome on the [mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users).


## Licensing

RabbitMQ server is [licensed under the MPL 2.0](LICENSE-MPL-RabbitMQ).


## Building From Source and Packaging

 * [Building RabbitMQ from Source](https://rabbitmq.com/build-server.html)
 * [Building RabbitMQ Distribution Packages](https://rabbitmq.com/build-server.html)


## Copyright

(c) 2007-2021 VMware, Inc. or its affiliates.

==> rabbitmq-server_3.9.13.orig.tar.xz: rabbitmq-server-3.9.13/README.md <==
[![Test](https://github.com/rabbitmq/rabbitmq-server/actions/workflows/test.yaml/badge.svg)](https://github.com/rabbitmq/rabbitmq-server/actions/workflows/test.yaml)

# RabbitMQ Server

[RabbitMQ](https://rabbitmq.com) is a [feature rich](https://rabbitmq.com/documentation.html), multi-protocol messaging broker. It supports:

 * AMQP 0-9-1
 * AMQP 1.0
 * MQTT 3.1.1
 * STOMP 1.0 through 1.2


## Installation

 * [Installation guides](https://rabbitmq.com/download.html) for various platforms
 * [Kubernetes Cluster Operator](https://www.rabbitmq.com/kubernetes/operator/operator-overview.html)
 * [Changelog](https://www.rabbitmq.com/changelog.html)
 * [Releases](https://github.com/rabbitmq/rabbitmq-server/releases) on GitHub
 * [Supported and unsupported series](https://www.rabbitmq.com/versions.html)
 * [Supported Erlang versions](https://www.rabbitmq.com/which-erlang.html)


## Tutorials & Documentation

 * [RabbitMQ tutorials](https://rabbitmq.com/getstarted.html)
 * [All documentation guides](https://rabbitmq.com/documentation.html)

Some key doc guides include

 * [CLI tools guide](https://rabbitmq.com/cli.html) 
 * [Clustering](https://www.rabbitmq.com/clustering.html) and [Cluster Formation](https://www.rabbitmq.com/cluster-formation.html) guides
 * [Configuration guide](https://rabbitmq.com/configure.html) 
 * [Client libraries and tools](https://rabbitmq.com/devtools.html)
 * [Monitoring](https://rabbitmq.com/monitoring.html) and [Prometheus/Grafana](https://www.rabbitmq.com/prometheus.html) guides
 * [Production checklist](https://rabbitmq.com/production-checklist.html)
 * [Quorum queues](https://rabbitmq.com/quorum-queues.html): a replicated, data safety- and consistency-oriented queue type
 * [Runnable tutorials](https://github.com/rabbitmq/rabbitmq-tutorials/)
 * [Documentation source](https://github.com/rabbitmq/rabbitmq-website/)


## Commercial Support

* [Commercial support](https://rabbitmq.com/services.html) from [VMware](https://vmware.com) for open source RabbitMQ

## Getting Help from the Community

 * [GitHub Discussions](https://github.com/rabbitmq/rabbitmq-server/discussions/)
 * [RabbitMQ mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users)
 * [Community Slack](https://rabbitmq-slack.herokuapp.com/)
 * `#rabbitmq` on Freenode


## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md) and our [development process overview](https://rabbitmq.com/github.html).

Questions about contributing, internals and so on are very welcome on the [mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users).


## Licensing

RabbitMQ server is [licensed under the MPL 2.0](LICENSE-MPL-RabbitMQ).


## Building From Source and Packaging

 * [Building RabbitMQ from Source](https://rabbitmq.com/build-server.html)
 * [Building RabbitMQ Distribution Packages](https://rabbitmq.com/build-server.html)


## Copyright

(c) 2007-2021 VMware, Inc. or its affiliates.
